NAME

Alien::YARA - Find or download and install the YARA malware analysis library

VERSION

Version v0.0.2

SYNOPSIS

In your Makefile.PL or Build.PL:

use Alien::Build::MM;
my $abmm = Alien::Build::MM->new;

WriteMakefile($abmm->mm_args(
    ...
    PREREQ_PM => {
        'Alien::YARA' => '0.01',
    },
));

In your Perl module code:

use Alien::YARA;
use FFI::Platypus;

my $ffi = FFI::Platypus->new( api => 2 );
$ffi->lib( Alien::YARA->dynamic_libs );

# Now attach your C functions
$ffi->attach( 'yr_initialize' => [] => 'int' );

DESCRIPTION

This module acts as an encapsulation layer for the YARA C library (libyara). It checks your host system to see if YARA is already installed via native package management (like apt, homebrew, or pkgconf). If it cannot find a suitable global version, it automatically downloads the official YARA source code, compiles it, and isolates the binaries locally within your Perl library tree.

This makes bundling dependencies for FFI-based modules like YaraFFI perfectly cross-platform across Linux, macOS, and Windows.

METHODS

This class inherits all methods from Alien::Base. The most critical ones for FFI usage are:

dist_dir

my $dir = Alien::YARA->dist_dir;

Returns the local installation directory if a share install was performed.

dynamic_libs

my @libs = Alien::YARA->dynamic_libs;
my $lib  = $libs[0];

Returns a list of paths to the shared objects or dynamic libraries (.so, .dylib, .dll). Pass this directly into your FFI::Platypus instantiation.

cflags

my $cflags = Alien::YARA->cflags;

Returns the compiler flags needed to compile an XS module against libyara.

libs

my $libs = Alien::YARA->libs;

Returns the linker flags needed to link an XS module against libyara.

SEE ALSO

AUTHOR

Mohammad Sajid Anwar, <mohammad.anwar at yahoo.com>

REPOSITORY

https://github.com/manwar/Alien-YARA

BUGS

Please report any bugs or feature requests through the web interface at https://github.com/manwar/Alien-YARA/issues. I will be notified and then you'll automatically be notified of progress on your bug as I make changes.

SUPPORT

You can find documentation for this module with the perldoc command.

perldoc Alien-YARA

You can also look for information at:

LICENSE AND COPYRIGHT

Copyright (C) 2026 Mohammad Sajid Anwar.

This program is free software; you can redistribute it and / or modify it under the terms of the the Artistic License (2.0). You may obtain a copy of the full license at: http://www.perlfoundation.org/artistic_license_2_0 Any use, modification, and distribution of the Standard or Modified Versions is governed by this Artistic License.By using, modifying or distributing the Package, you accept this license. Do not use, modify, or distribute the Package, if you do not accept this license. If your Modified Version has been derived from a Modified Version made by someone other than you,you are nevertheless required to ensure that your Modified Version complies with the requirements of this license. This license does not grant you the right to use any trademark, service mark, tradename, or logo of the Copyright Holder. This license includes the non-exclusive, worldwide, free-of-charge patent license to make, have made, use, offer to sell, sell, import and otherwise transfer the Package with respect to any patent claims licensable by the Copyright Holder that are necessarily infringed by the Package. If you institute patent litigation (including a cross-claim or counterclaim) against any party alleging that the Package constitutes direct or contributory patent infringement,then this Artistic License to you shall terminate on the date that such litigation is filed. Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.